@@ -157,8 +157,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
             r, theta, t, self.R_0,
             inside_sphere=True,
         )
-        out = self.radial_mode_superposition(radial_func, r, theta, t, mode)
-        return out
+        return self.radial_mode_superposition(radial_func, r, theta, t, mode)
 
     def tangential_particle_velocity(
         self,
@@ -181,11 +180,10 @@ class ScatteringField(BaseYosioka, BaseScattering):
             r, theta, t, self.R_0,
             inside_sphere=True,
         )
-        out = self.tangential_mode_superposition(
+        return self.tangential_mode_superposition(
             radial_func, r, theta, t,
             mode,
         )
-        return out
 
     # -------------------------------------------------------------------------
     # Velocity Amplitudes and Velocity Potentials
