@@ -1,5 +1,4 @@
 from abc import abstractmethod
-from enum import auto
 
 from osaft import WaveType
 from osaft.core.backgroundfields import WrongWaveTypeError
@@ -15,7 +14,7 @@ class HelperARF:
         pass
 
     def test_wrong_wave_type_error(self):
-        WaveType.WRONGWAVETYPE = auto()
+        WaveType.WRONGWAVETYPE = 3, 'wrong wave type'
         self.cls.wave_type = WaveType.WRONGWAVETYPE
         self.assertRaises(WrongWaveTypeError, self.cls.compute_arf)
 
